@@ -174,6 +174,14 @@ _SEQDB = {
     '< CSI >83;40003;0c' : 'DA2 Response: could be GNU Screen 4.0.3',
     '< CSI >83;40100;0c' : 'DA2 Response: could be GNU Screen 4.1.0',
     '< CSI >85;95;c'     : 'DA2 Response: could be rxvt-unicode',
+    '< CSI 1t'           : 'CSI 11 t Response: window is open',
+    '< CSI 2t'           : 'CSI 11 t Response: window is iconified',
+    '< CSI 3;[2]t'       : 'CSI 13 t Response: window position (x, y) is (%d, %d)',
+    '< CSI 4;[2]t'       : 'CSI 14 t Response: window size (height, width) in pixels is (%d, %d)',
+    '< CSI 8;[2]t'       : 'CSI 18 t Response: text area size (height, width) in characters is (%d, %d)',
+    '< CSI 9;[2]t'       : 'CSI 19 t Response: screen size (height, width) in characters is (%d, %d)',
+    '< ESC ]L<ST>'       : 'OSC L / CSI 20 t Response: report icon label',
+    '< ESC ]l<ST>'       : 'OSC l / CSI 21 t Response: report title',
     '< ESC O P'          : 'F1 key (xterm)',
     '< ESC O Q'          : 'F2 key (xterm)',
     '< ESC O R'          : 'F3 key (xterm)',
@@ -241,7 +249,13 @@ _SEQDB = {
     '> ESC ]13<ST>'      : 'OSC 13 / get or set mouse foreground color',
     '> ESC ]14<ST>'      : 'OSC 13 / get or set mouse background color',
     '> ESC ]51<ST>'      : 'OSC 51 / reserved for Emacs',
+    '> ESC ]52;i<ST>'    : 'OSC 52 / term+-edit-insert (term+)',
+    '> ESC ]52;h<ST>'    : 'OSC 52 / term+-shell-history (term+)',
     '> ESC ]52<ST>'      : 'OSC 52 - PASTE64 / base64 clipboard read/write operation (xterm)',
+    '> ESC ]5379<ST>'    : 'OSC 5379 / exec command or set (mlterm)',
+    '> ESC ]5380<ST>'    : 'OSC 5380 / get pty (mlterm)',
+    '> ESC ]5381<ST>'    : 'OSC 5381 / get GUI menu (mlterm)',
+    '> ESC ]5383<ST>'    : 'OSC 5383 / set & save (mlterm)',
     '> ESC ]8900<ST>'    : 'OSC 8890 - GWREPT / glyph width report (yaft)',
     '> ESC ^<ST>'        : 'PM / private message',
     '> ESC _<ST>'        : 'APC / application program command',
@@ -386,11 +400,11 @@ _SEQDB = {
     '> CSI T'            : 'SD 1 / scroll down',
     '> CSI [1]T'         : 'SD / scroll down %s times',
     '> CSI [6]T'         : 'Initiate highlight mouse tracking (startx=%s,starty=%s,endx=%s,endy=%s,mousex=%s,mousey=%s)',
-    '> CSI >T'           : 'Title Mode Setting (xterm)',
-    '> CSI >0T'          : 'Title Mode Setting (xterm) 0: Do not set window/icon labels using hexadecimal',
-    '> CSI >1T'          : 'Title Mode Setting (xterm) 1: Do not query window/icon labels using hexadecimal',
-    '> CSI >2T'          : 'Title Mode Setting (xterm) 2: Do not set window/icon labels using UTF-8',
-    '> CSI >3T'          : 'Title Mode Setting (xterm) 3: Do not query window/icon labels using UTF-8',
+    '> CSI >T'           : 'Title Mode - Reset (xterm)',
+    '> CSI >0T'          : 'Title Mode - Reset (xterm) 0: Do not set window/icon labels using hexadecimal',
+    '> CSI >1T'          : 'Title Mode - Reset (xterm) 1: Do not query window/icon labels using hexadecimal',
+    '> CSI >2T'          : 'Title Mode - Reset (xterm) 2: Do not set window/icon labels using UTF-8',
+    '> CSI >3T'          : 'Title Mode - Reset (xterm) 3: Do not query window/icon labels using UTF-8',
     '> CSI X'            : 'ECH / erase characters',
     '> CSI [0]X'         : 'ECH 1 / erase a character',
     '> CSI Z'            : 'CBT / cursor backward tabulation',
@@ -589,13 +603,113 @@ _SEQDB = {
     '> CSI r'            : 'DECSTBM / set top and bottom margins',
     '> CSI ?s'           : 'save DEC private mode values',
     '> CSI ?r'           : 'restore DEC private mode values',
+    '> CSI [0]s'         : 'Save cursor (ANSI.SYS)',
+    '> CSI [0]u'         : 'Restore cursor (ANSI.SYS)',
     '> CSI t'            : 'DECSLPP or Window Manipulation (dtterm)',
+    '> CSI [1]t'         : 'DECSLPP / Resize to %d lines',
     '> CSI 1t'           : 'Window Manipulation (dtterm) 1: de-iconify window',
     '> CSI 2t'           : 'Window Manipulation (dtterm) 2: iconify window',
     '> CSI 3;[2]t'       : 'Window Manipulation (dtterm) 3: move window (%s, %s)',
-    '> CSI 4;[2]t'       : 'Window Manipulation (dtterm) 4: resize window in pixels (%s, %s)'
+    '> CSI 4;[2]t'       : 'Window Manipulation (dtterm) 4: resize window to given height and width in pixels (%s, %s)',
+    '> CSI 5t'           : 'Window Manipulation (dtterm) 5: raise the window to the front of the stacking order',
+    '> CSI 6t'           : 'Window Manipulation (dtterm) 6: lower the window to the bottom of the stacking order',
+    '> CSI 7t'           : 'Window Manipulation (dtterm) 7: reflesh the window',
+    '> CSI 8;[2]t'       : 'Window Manipulation (dtterm) 8: resize the text area to given height and width in characters (%s, %s)',
+    '> CSI 9;1t'         : 'Window Manipulation (dtterm) 9: maximize the window',
+    '> CSI 9;2t'         : 'Window Manipulation (dtterm) 9: maximize the window vertically',
+    '> CSI 9;3t'         : 'Window Manipulation (dtterm) 9: maximize the window horizontally',
+    '> CSI 10;0t'        : 'Window Manipulation (dtterm) 10: undo full-screen mode',
+    '> CSI 10;1t'        : 'Window Manipulation (dtterm) 10: change to full-screen',
+    '> CSI 10;2t'        : 'Window Manipulation (dtterm) 10: toggle full-screen',
+    '> CSI 11t'          : 'Window Manipulation (dtterm) 11: report the window state',
+    '> CSI 13t'          : 'Window Manipulation (dtterm) 13: report the window position',
+    '> CSI 14t'          : 'Window Manipulation (dtterm) 14: report the window size in pixels',
+    '> CSI 18t'          : 'Window Manipulation (dtterm) 18: report the text area size in characters',
+    '> CSI 19t'          : 'Window Manipulation (dtterm) 19: report the screen size in characters',
+    '> CSI 20t'          : 'Window Manipulation (dtterm) 20: report the window\'s icon label',
+    '> CSI 21t'          : 'Window Manipulation (dtterm) 21: report the window\'s title',
+    '> CSI 22;0t'        : 'Window Manipulation (dtterm) 22: save icon and window title on stack',
+    '> CSI 22;1t'        : 'Window Manipulation (dtterm) 22: save icon title on stack',
+    '> CSI 22;2t'        : 'Window Manipulation (dtterm) 22: save window title on stack',
+    '> CSI 23;0t'        : 'Window Manipulation (dtterm) 23: restore icon and window title on stack',
+    '> CSI 23;1t'        : 'Window Manipulation (dtterm) 23: restore icon title on stack',
+    '> CSI 23;2t'        : 'Window Manipulation (dtterm) 23: restore window title on stack',
+    '> CSI $t'           : 'DECRARA / reverse attributes in rectangular area',
+    '> CSI [5]$t'        : 'DECRARA / reverse attributes in rectangular area - top=%d, left=%d, bottom=%d, right=%d, attribute=%d',
+    '> CSI >t'           : 'Title Mode - Set (xterm)',
+    '> CSI >0t'          : 'Title Mode - Set (xterm) 0: Set window/icon labels using hexadecimal',
+    '> CSI >1t'          : 'Title Mode - Set (xterm) 1: Query window/icon labels using hexadecimal',
+    '> CSI >2t'          : 'Title Mode - Set (xterm) 2: Set window/icon labels using UTF-8',
+    '> CSI >3t'          : 'Title Mode - Set (xterm) 3: Query window/icon labels using UTF-8',
+    '> CSI <SP>t'        : 'DECSWBV / set warning bell volume',
+    '> CSI [1]<SP>t'     : 'DECSWBV / set warning bell volume to %d',
+    '> CSI u'            : 'Restore cursor (ANSI.SYS)',
+    '> CSI <SP>u'        : 'DECSMBV / set margin bell volume',
+    '> CSI [1]<SP>u'     : 'DECSMBV / set margin bell volume to %d',
+    '> CSI $v'           : 'DECCRA / copy rectangular area',
+    '> CSI \'w'          : 'DECEFR / enable filter rectangle',
+    '> CSI x'            : 'DECRECTPARM / request terminal parameters',
+    '> CSI *x'           : 'DECSACE / select attribute change extent',
+    '> CSI *y'           : 'DECRQCRA / request checksum of rectangular area',
+    '> CSI $x'           : 'DECFRA / fill rectangular area',
+    '> CSI \'z'          : 'DECELR / enable locator reporting ',
+    '> CSI $z'           : 'DECERA / erase rectangular area',
+    '> CSI [4]$z'        : 'DECErA / erase rectangular area - top=%d, left=%d, bottom=%d, right=%d',
 }
 
+_DEFAULT_CONF = """
+#
+# expression := <io-prefix>, <seq>,
+# io-prefix := '<' | '>' // <: input, >: outut
+# seq := ss2 | ss3 | esc | csi | cstr | cchar
+# ss2 := 'ESC N ' <any-byte>
+# ss3 := 'ESC O ' <any-byte>
+# esc := 'ESC ', ( <esc-ibytes>, <esc-fbyte>
+#                | <esc-fbyte> )
+# csi := 'CSI ', ( <csi-pbytes>, <csi-ibytes>, <csi-fbyte>
+#                | <csi-ibytes>, <csi-fbyte>
+#                | <csi-fbyte> )
+# cstr := 'ESC ', <cstr-prefix>, ' ', <cstr-body>, '<ST>'
+# cchar := '<' . <mnemonic> . '>'
+#
+_SEQDB_OVERLAY = {
+    '< CSI 17~'          : '!tracer.set_enabled() if tracer.is_disabled() else tracer.set_disabled()',
+    '< CSI 18~'          : '!controller.resume() if controller.is_suspended() else controller.set_break()',
+    '< CSI 19~'          : '!controller.set_normal_step()',
+    '< CSI 20~'          : '!controller.set_fuzzy_step()',
+}
+
+def get():
+    return _SEQDB_OVERLAY
+
+"""
+
+import os
+
+
+rcdir = os.path.join(os.getenv("HOME"), ".trachet")
+if not os.path.exists(rcdir):
+    os.makedirs(rcdir)
+
+confpath = os.path.join(rcdir, "conf.py")
+if not os.path.exists(confpath):
+    f = open(confpath, "w")
+    try:
+        f.write(_DEFAULT_CONF)
+    finally:
+        f.close()
+
+import sys
+sys.path.insert(0, rcdir)
+try:
+    import conf 
+    for key, value in conf.get().items():
+        _SEQDB[key] = value
+except:
+    print str(sys.exc_info())
+finally:
+    sys.path.pop(0)
+
 def get():
     return _SEQDB
 
