@@ -260,7 +260,7 @@ class DefaultParser(Parser):
                 elif c == 0x7f: # control character
                     context.dispatch_char(c)
                 else:
-                    seq = [0x1b]
+                    seq = [0x1b, c]
                     context.dispatch_invalid(seq)
                     self.__parse_state = _STATE_GROUND
 
@@ -286,7 +286,7 @@ class DefaultParser(Parser):
                 elif c == 0x7f: # control character
                     context.dispatch_char(c)
                 else:
-                    seq = [0x1b] + self.__ibytes
+                    seq = [0x1b] + self.__ibytes + [c]
                     context.dispatch_invalid(seq)
                     self.__parse_state = _STATE_GROUND
 
@@ -318,7 +318,7 @@ class DefaultParser(Parser):
                 elif c == 0x7f: # control character
                     context.dispatch_char(c)
                 else:
-                    seq = [0x1b, 0x5b] + self.__pbytes
+                    seq = [0x1b, 0x5b] + self.__pbytes + [c]
                     context.dispatch_invalid(seq)
                     self.__parse_state = _STATE_GROUND
                     #raise ParseException("Unknown CSI seqnence detected.")
@@ -334,7 +334,7 @@ class DefaultParser(Parser):
                     self.__ibytes = []
                     self.__parse_state = _STATE_ESC
                 elif c == 0x18 or c == 0x1a:
-                    seq = [0x1b, 0x5b] + self.__pbytes + self.__ibytes
+                    seq = [0x1b, 0x5b] + self.__pbytes + self.__ibytes + [c]
                     context.dispatch_invalid(seq)
                     context.dispatch_char(c)
                     self.__parse_state = _STATE_GROUND
@@ -342,9 +342,8 @@ class DefaultParser(Parser):
                     context.dispatch_char(c)
                 elif c <= 0x2f: # intermediate, SP to /
                     self.__ibytes.append(c)
-                    self.__parse_state = _STATE_CSI_INTERMEDIATE
                 elif c <= 0x3f:
-                    seq = [0x1b, 0x5b] + self.__pbytes + self.__ibytes
+                    seq = [0x1b, 0x5b] + self.__pbytes + self.__ibytes + [c]
                     context.dispatch_invalid(seq)
                     self.__parse_state = _STATE_GROUND
                 elif c <= 0x7e: # Final byte, @ to ~
@@ -353,7 +352,7 @@ class DefaultParser(Parser):
                 elif c == 0x7f: # control character
                     context.dispatch_char(c)
                 else:
-                    seq = [0x1b, 0x5b] + self.__pbytes + self.__ibytes
+                    seq = [0x1b, 0x5b] + self.__pbytes + self.__ibytes + [c]
                     context.dispatch_invalid(seq)
                     self.__parse_state = _STATE_GROUND
 
@@ -706,6 +705,8 @@ class DefaultPTY(PTY):
                   | termios.IGNCR 
                   | termios.ICRNL)
 
+        term[1] &= ~termios.ONLCR 
+
         ## c_lflag
         term[3] = term[3] &~ (termios.ECHO | termios.ICANON)
 
@@ -785,10 +786,6 @@ class DefaultPTY(PTY):
                             data = self.read()
                             if data:
                                 yield None, data, None
-                except OSError, e:
-                    no, msg = e
-                    #if no == errno.EIO:
-                    return
                 except select.error, e:
                     no, msg = e
                     if no == errno.EINTR: # The call was interrupted by a signal
@@ -842,6 +839,14 @@ class Session:
         except ValueError:
             pass
 
+        def onclose(no, frame):
+            sys.exit(0)
+
+        try:
+            signal.signal(signal.SIGCHLD, onclose)
+        except ValueError:
+            pass
+
         inputhandler.handle_start(inputcontext)
         outputhandler.handle_start(outputcontext)
         inputhandler.handle_draw(inputcontext)
@@ -871,6 +876,12 @@ class Session:
                     inputhandler.handle_resize(inputcontext, row, col)
                     outputhandler.handle_resize(outputcontext, row, col)
                     self._dirty = True
+        except OSError, e:
+            no, msg = e
+            if no == errno.EIO:
+                return
+            else:
+                raise e
         finally:
             inputhandler.handle_end(inputcontext)
             outputhandler.handle_end(outputcontext)
